@@ -27,7 +27,7 @@ plot.confScore <- function(x,
   })
   if (smooth==TRUE){
     nix <- lapply(1:length(x$models),function(m){
-      smooth3 <- prodlim:::meanNeighbors(x=x$models[[m]]$meanPred,y=x$models[[m]]$score,bandwidth=NULL)
+      smooth3 <- prodlim::meanNeighbors(x=x$models[[m]]$meanPred,y=x$models[[m]]$score,bandwidth=NULL)
       lines(averageY~uniqueX,data=smooth3,col=col[m],lwd=3)
     })
   }
